==> jc-1.4.0.tar.gz: javax/security/auth/callback/PasswordCallback.h <==
// public class javax.security.auth.callback.PasswordCallback

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8dbd32af5c351211 javax_security_auth_callback_PasswordCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_PasswordCallback_H_
#define _JC_javax_security_auth_callback_PasswordCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_PasswordCallback$sub_refs	_jc_javax_security_auth_callback_PasswordCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_PasswordCallback$sub_nonrefs	_jc_javax_security_auth_callback_PasswordCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_PasswordCallback$refs	_jc_javax_security_auth_callback_PasswordCallback$refs;
typedef struct _jc_javax_security_auth_callback_PasswordCallback$nonrefs	_jc_javax_security_auth_callback_PasswordCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_PasswordCallback$object	_jc_javax_security_auth_callback_PasswordCallback$object;

typedef const struct _jc_javax_security_auth_callback_PasswordCallback$vmethods	_jc_javax_security_auth_callback_PasswordCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_PasswordCallback$vtable	_jc_javax_security_auth_callback_PasswordCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_PasswordCallback$vtype	_jc_javax_security_auth_callback_PasswordCallback$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_PasswordCallback$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods
extern void _jc_javax_security_auth_callback_PasswordCallback$method$clearPassword$5500d515bfb0eaa8(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *);
extern _jc_char_array *_jc_javax_security_auth_callback_PasswordCallback$method$getPassword$6adf0c63e283126f(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_PasswordCallback$method$getPrompt$ad6bd756fb4800ba(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *);
extern jboolean _jc_javax_security_auth_callback_PasswordCallback$method$isEchoOn$5d2d4c483da9ca63(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *);
extern void _jc_javax_security_auth_callback_PasswordCallback$method$setPassword$9c12620206768420(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_char_array *);
extern void _jc_javax_security_auth_callback_PasswordCallback$method$setPrompt$7b347b9990ff5882(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$clearPassword$5500d515bfb0eaa8;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$getPassword$6adf0c63e283126f;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$getPrompt$ad6bd756fb4800ba;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$isEchoOn$5d2d4c483da9ca63;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$setPassword$9c12620206768420;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$setPrompt$7b347b9990ff5882;

// Virtual methods structure
struct _jc_javax_security_auth_callback_PasswordCallback$vmethods {
	void	(*clearPassword$5500d515bfb0eaa8)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *);
	_jc_char_array	*(*getPassword$6adf0c63e283126f)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *);
	struct _jc_java_lang_String$object	*(*getPrompt$ad6bd756fb4800ba)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *);
	jboolean	(*isEchoOn$5d2d4c483da9ca63)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *);
	void	(*setPassword$9c12620206768420)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_char_array *);
	void	(*setPrompt$7b347b9990ff5882)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_javax_security_auth_callback_PasswordCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_PasswordCallback$vmethods	javax_security_auth_callback_PasswordCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_PasswordCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_PasswordCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_PasswordCallback$sub_refs {
	struct _jc_java_lang_String$object	*prompt;
	_jc_char_array	*inputPassword;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_PasswordCallback$refs {
    _jc_javax_security_auth_callback_PasswordCallback$sub_refs	javax_security_auth_callback_PasswordCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_PasswordCallback$sub_nonrefs {
	jboolean	echoOn;
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_PasswordCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_PasswordCallback$sub_nonrefs	javax_security_auth_callback_PasswordCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_PasswordCallback$object {
	_jc_javax_security_auth_callback_PasswordCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_PasswordCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_PasswordCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_PasswordCallback$vtype _jc_javax_security_auth_callback_PasswordCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_PasswordCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_PasswordCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_PasswordCallback_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/callback/PasswordCallback.h <==
// public class javax.security.auth.callback.PasswordCallback

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8dbd32af5c351211 javax_security_auth_callback_PasswordCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_PasswordCallback_H_
#define _JC_javax_security_auth_callback_PasswordCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_PasswordCallback$sub_refs	_jc_javax_security_auth_callback_PasswordCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_PasswordCallback$sub_nonrefs	_jc_javax_security_auth_callback_PasswordCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_PasswordCallback$refs	_jc_javax_security_auth_callback_PasswordCallback$refs;
typedef struct _jc_javax_security_auth_callback_PasswordCallback$nonrefs	_jc_javax_security_auth_callback_PasswordCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_PasswordCallback$object	_jc_javax_security_auth_callback_PasswordCallback$object;

typedef const struct _jc_javax_security_auth_callback_PasswordCallback$vmethods	_jc_javax_security_auth_callback_PasswordCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_PasswordCallback$vtable	_jc_javax_security_auth_callback_PasswordCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_PasswordCallback$vtype	_jc_javax_security_auth_callback_PasswordCallback$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_PasswordCallback$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_security_auth_callback_PasswordCallback$method$clearPassword$5500d515bfb0eaa8(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *) _JC_JCNI_ATTR;
extern _jc_char_array *_jc_javax_security_auth_callback_PasswordCallback$method$getPassword$6adf0c63e283126f(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_PasswordCallback$method$getPrompt$ad6bd756fb4800ba(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_security_auth_callback_PasswordCallback$method$isEchoOn$5d2d4c483da9ca63(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_PasswordCallback$method$setPassword$9c12620206768420(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_char_array *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_PasswordCallback$method$setPrompt$7b347b9990ff5882(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$clearPassword$5500d515bfb0eaa8;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$getPassword$6adf0c63e283126f;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$getPrompt$ad6bd756fb4800ba;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$isEchoOn$5d2d4c483da9ca63;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$setPassword$9c12620206768420;
extern _jc_method _jc_javax_security_auth_callback_PasswordCallback$method_info$setPrompt$7b347b9990ff5882;

// Virtual methods structure
struct _jc_javax_security_auth_callback_PasswordCallback$vmethods {
	void	(*clearPassword$5500d515bfb0eaa8)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *) _JC_JCNI_ATTR;
	_jc_char_array	*(*getPassword$6adf0c63e283126f)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPrompt$ad6bd756fb4800ba)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *) _JC_JCNI_ATTR;
	jboolean	(*isEchoOn$5d2d4c483da9ca63)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *) _JC_JCNI_ATTR;
	void	(*setPassword$9c12620206768420)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_char_array *) _JC_JCNI_ATTR;
	void	(*setPrompt$7b347b9990ff5882)(_jc_env *, struct _jc_javax_security_auth_callback_PasswordCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_callback_PasswordCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_PasswordCallback$vmethods	javax_security_auth_callback_PasswordCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_PasswordCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_PasswordCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_PasswordCallback$sub_refs {
	struct _jc_java_lang_String$object	*prompt;
	_jc_char_array	*inputPassword;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_PasswordCallback$refs {
    _jc_javax_security_auth_callback_PasswordCallback$sub_refs	javax_security_auth_callback_PasswordCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_PasswordCallback$sub_nonrefs {
	jboolean	echoOn;
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_PasswordCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_PasswordCallback$sub_nonrefs	javax_security_auth_callback_PasswordCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_PasswordCallback$object {
	_jc_javax_security_auth_callback_PasswordCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_PasswordCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_PasswordCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_PasswordCallback$vtype _jc_javax_security_auth_callback_PasswordCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_PasswordCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_PasswordCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_PasswordCallback_H_ */
